@@ -151,6 +151,14 @@ Returns 0 if date is between C<from()> and C<till()> dates.
 
 Returns 1 otherwise.
 
+=head4 clone()
+
+Clones object.
+
+=head4 HOOK_CLONE()
+
+Hook for Panda::Lib::clone().
+
 =head1 OPERATOR OVERLOAD RULES
 
 See screenshot L<http://crazypanda.ru/v/clip2net/p/F/0WuXfVRKMM.png>
